reset
# ========================================================================================================
# Fitting models to data.

# Gaussian function, mu is the math expectation, sigma is the std.
f(x, A, mu, sigma) = A * exp(-0.5 * ((x - mu) / sigma)**2) / (sigma * sqrt(2 * pi))

set samples 500

# Plot data
  plot "data/data.dat" using 1:2 with linespoints pt 7 ps 0.5 lc "0xFF0000" lw 0.5 title "Exp1"
replot "data/data.dat" using 1:4 with linespoints pt 7 ps 0.5 lc "0x00AA00" lw 0.5 title "Exp2"
replot "data/data.dat" using 1:6 with linespoints pt 7 ps 0.5 lc "0x0000FF" lw 0.5 title "Exp3"

A1 = 50; mu1 = 15; sigma1 = 2;
A2 = 50; mu2 = 15; sigma2 = 2;
A3 = 50; mu3 = 15; sigma3 = 2;

# Fit models for our data sets
fit f(x, A1, mu1, sigma1) "data/data.dat" using 1:2 via A1, mu1, sigma1
fit f(x, A2, mu2, sigma2) "data/data.dat" using 1:4 via A2, mu2, sigma2
fit f(x, A3, mu3, sigma3) "data/data.dat" using 1:6 via A3, mu3, sigma3

# Plot the models.
replot f(x, A1, mu1, sigma1) with lines lw 3 lc "0xFF0000" title "Model 1"
replot f(x, A2, mu2, sigma2) with lines lw 3 lc "0x00AA00" title "Model 2"
replot f(x, A3, mu3, sigma3) with lines lw 3 lc "0x0000FF" title "Model 3"

# ---------------------------------------
# Set the appropriate ranges
set xrange [0:30]
set yrange [-1:*]

set xzeroaxis

# ---------------------------------------
# Let us add some labels. At this point I do not need the top title.
set ylabel "Probability density / a.u." 
set xlabel "Property / a.u."
replot

# ========================================================================================================
# Print the models' paramters at the end.
print "============================================================"
print "Model1: ", A1, mu1, sigma1
print "Model2: ", A2, mu2, sigma2
print "Model3: ", A3, mu3, sigma3

# ========================================================================================================

