reset
# ========================================================================================================
# Plotting and labeling models for discussion. 
set samples 500

# Gaussian function, mu is the math expectation, sigma is the std.
f(x, A, mu, sigma) = A * exp(-0.5 * ((x - mu) / sigma)**2) / (sigma * sqrt(2 * pi))

# Refit the models here again, rather than use previously found values.
A1 = 50; mu1 = 15; sigma1 = 2;
A2 = 50; mu2 = 15; sigma2 = 2;
A3 = 50; mu3 = 15; sigma3 = 2;

# Fit models for our data sets
fit f(x, A1, mu1, sigma1) "data/data.dat" using 1:2 via A1, mu1, sigma1
fit f(x, A2, mu2, sigma2) "data/data.dat" using 1:4 via A2, mu2, sigma2
fit f(x, A3, mu3, sigma3) "data/data.dat" using 1:6 via A3, mu3, sigma3

# Plot the models.
  plot f(x, A1, mu1, sigma1) with lines lw 3 lc "red" title "Model 1"
replot f(x, A2, mu2, sigma2) with lines lw 3 lc "0x00AA00" title "Model 2"
replot f(x, A3, mu3, sigma3) with lines lw 3 lc "blue" title "Model 3"

# Plot the reference model 
replot f(x, 50., 15., 2.) with lines lw 3 lc "black" dt 2 title "Reference"

# ---------------------------------------
# Set the appropriate ranges
set xrange [0:30]
set yrange [-1:*]

set yzeroaxis
set xzeroaxis
replot

# ---------------------------------------
# Let us add some labels. At this point I do not need the top title.
set ylabel "Probability density / a.u." 
set xlabel "Property / a.u."
replot

# ---------------------------------------
set arrow 1 from mu1,0 to mu1,f(mu1, A1, mu1, sigma1) nohead lw 1 dt 2 lc "red"
set arrow 2 from mu2,0 to mu2,f(mu2, A2, mu2, sigma2) nohead lw 1 dt 2 lc "0x00AA00"
set arrow 3 from mu3,0 to mu3,f(mu3, A3, mu3, sigma3) nohead lw 1 dt 2 lc "blue"
set arrow 4 from 15,0 to 15,f(15, 50, 15, 2) nohead lw 1 dt 2 lc "black"


set label 1 sprintf("{/Symbol m}=%.3f, {/Symbol s}=%.3f", mu1, sigma1) at 20.0, 6.0 tc "red"
set label 2 sprintf("{/Symbol m}=%.3f, {/Symbol s}=%.3f", mu2, sigma2) at 17.5,10.5 tc "0x00AA00"
set label 3 sprintf("{/Symbol m}=%.3f, {/Symbol s}=%.3f", mu3, sigma3) at 11.5, 8.5 right tc "blue"
set label 4 sprintf("{/Symbol m}=%.3f, {/Symbol s}=%.3f", 15, 2) at 14.0,10.0 right tc "black"

set arrow 11 from 16.5,f(16.5, A1, mu1, sigma1) to 20.0,5.7 nohead lw 1 lc "red"

replot

# ========================================================================================================
print "============================================================"
print "Model1: ", A1, mu1, sigma1
print "Model2: ", A2, mu2, sigma2
print "Model3: ", A3, mu3, sigma3

# ========================================================================================================

