reset
# ========================================================================================================
# Multiplot layout.

# Gaussian function, mu is the math expectation, sigma is the std.
f(x, A, mu, sigma) = A * exp(-0.5 * ((x - mu) / sigma)**2) / (sigma * sqrt(2 * pi))

# --------------------------------------
set samples 500

set multiplot layout 1,2 

# --------------------------------------
# Fit models for our data

A1 = 50; mu1 = 15; sigma1 = 2;
A2 = 50; mu2 = 15; sigma2 = 2;
A3 = 50; mu3 = 15; sigma3 = 2;

# Fit models for our data sets
fit f(x, A1, mu1, sigma1) "data/data.dat" using 1:2 via A1, mu1, sigma1
fit f(x, A2, mu2, sigma2) "data/data.dat" using 1:4 via A2, mu2, sigma2
fit f(x, A3, mu3, sigma3) "data/data.dat" using 1:6 via A3, mu3, sigma3

# --------------------------------------
# Graph 1
# --------------------------------------
# Set the appropriate ranges
set xrange [0:30]
set yrange [-1:*]

set yzeroaxis
set xzeroaxis

# Add labels.
set ylabel "Probability density / a.u." 
set xlabel "Property / a.u."

# Plot the reference model

plot "data/data.dat" using 1:2 with linespoints pt 7 ps 0.5 lc "0xFF0000" lw 0.5 title "Exp1", \
     	"data/data.dat" using 1:4 with linespoints pt 7 ps 0.5 lc "0x00AA00" lw 0.5 title "Exp2", \
     	"data/data.dat" using 1:6 with linespoints pt 7 ps 0.5 lc "0x0000FF" lw 0.5 title "Exp3", \
	f(x, A1, mu1, sigma1) with lines lw 3 lc "0xFF0000" title "Model 1", \
	f(x, A2, mu2, sigma2) with lines lw 3 lc "0x00AA00" title "Model 2", \
	f(x, A3, mu3, sigma3) with lines lw 3 lc "0x0000FF" title "Model 3", \


# --------------------------------------
# Graph 2
# --------------------------------------
# Plot the models.

# Set the appropriate ranges
set xrange [0:30]
set yrange [-1:*]

set yzeroaxis
set xzeroaxis

# Add labels.
set ylabel "Probability density / a.u." 
set xlabel "Property / a.u."

plot f(x, A1, mu1, sigma1) with lines lw 3 lc "0xFF0000" title "Model 1", \
	f(x, A2, mu2, sigma2) with lines lw 3 lc "0x00AA00" title "Model 2", \
	f(x, A3, mu3, sigma3) with lines lw 3 lc "0x0000FF" title "Model 3", \
	f(x, 50., 15., 2.) with lines lw 2 lc "black" dt 2 title "Reference"

unset multiplot
# ========================================================================================================
print "============================================================"
print "Model1: ", A1, mu1, sigma1
print "Model2: ", A2, mu2, sigma2
print "Model3: ", A3, mu3, sigma3

# ========================================================================================================

