reset
# ========================================================================================================
# Finance time series data 
set ylabel "EURUSD"

# Time data is the number of seconds from Jan. 1st 1970.
# Strings will be converted to integers.

set timefmt "%Y-%m-%d %H:%M:%S"

set xdata time
set xlabel "Year\nDate"
set format x "%Y\n%d/%m"

# Note that the time data for x takes 2 colums, so the "open" data is in the 3rd column.
plot "data/eurusd.dat" using 1:3 with fsteps lw 1 lc "red" title "EURUSD, min"

# Shifts are required to move the origin at the begining of the fit range.
# The nubers are large and the accuracy of the fit routine is not sufficient to
# deal with it.
# The trend is the slope. The slope does not change by this transformation.

shift0 = 1.56760e9
a0 = 0.1; b0 = 1.;
tr0(x) = a0 * (x - shift0) + b0

shift1 = 1.56768e9
a1 = -0.1; b1 = 1.;
tr1(x) = a1 * (x - shift1) + b1

# Fit the long and short trends.
fit tr0(x) "data/eurusd.dat" using 1:3 via a0,b0
fit [shift1:*] tr1(x) "data/eurusd.dat" using 1:3 via a1,b1

# Plot the trends over the relevant ranges.
replot tr0(x) with lines lw 3 dt 2 lc "blue" title "Week trend"
replot [shift1:*] tr1(x) with lines lw 3 dt 2 lc "0x00aa00" title "Short time trend"

# Move the legend out of the way.
set key top left
replot

# ========================================================================================================

